==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/messaging/v1/SubscriptionStatusBuilder.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SubscriptionStatusBuilder extends SubscriptionStatusFluentImpl<SubscriptionStatusBuilder> implements VisitableBuilder<SubscriptionStatus,SubscriptionStatusBuilder> {

    SubscriptionStatusFluent<?> fluent;
    Boolean validationEnabled;

    public SubscriptionStatusBuilder() { 
        this(true);
    }


    public SubscriptionStatusBuilder(Boolean validationEnabled) { 
        this(new SubscriptionStatus(), validationEnabled);
    }


    public SubscriptionStatusBuilder(SubscriptionStatusFluent<?> fluent) { 
        this(fluent, true);
    }


    public SubscriptionStatusBuilder(SubscriptionStatusFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new SubscriptionStatus(), validationEnabled);
    }


    public SubscriptionStatusBuilder(SubscriptionStatusFluent<?> fluent,SubscriptionStatus instance) { 
        this(fluent, instance, true);
    }


    public SubscriptionStatusBuilder(SubscriptionStatusFluent<?> fluent,SubscriptionStatus instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withAnnotations(instance.getAnnotations()); 
        fluent.withConditions(instance.getConditions()); 
        fluent.withObservedGeneration(instance.getObservedGeneration()); 
        fluent.withPhysicalSubscription(instance.getPhysicalSubscription()); 
        this.validationEnabled = validationEnabled; 
    }


    public SubscriptionStatusBuilder(SubscriptionStatus instance) { 
        this(instance,true);
    }


    public SubscriptionStatusBuilder(SubscriptionStatus instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withAnnotations(instance.getAnnotations()); 
        this.withConditions(instance.getConditions()); 
        this.withObservedGeneration(instance.getObservedGeneration()); 
        this.withPhysicalSubscription(instance.getPhysicalSubscription()); 
        this.validationEnabled = validationEnabled; 
    }


    public SubscriptionStatus build() {
        SubscriptionStatus buildable = new SubscriptionStatus(fluent.getAnnotations(),fluent.getConditions(),fluent.getObservedGeneration(),fluent.getPhysicalSubscription());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SubscriptionStatusBuilder that = (SubscriptionStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.2.0-sources.jar: annotations/io/fabric8/knative/messaging/v1/SubscriptionStatusBuilder.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SubscriptionStatusBuilder extends SubscriptionStatusFluentImpl<SubscriptionStatusBuilder> implements VisitableBuilder<SubscriptionStatus,SubscriptionStatusBuilder> {

    SubscriptionStatusFluent<?> fluent;
    Boolean validationEnabled;

    public SubscriptionStatusBuilder() {
        this(true);
    }

    public SubscriptionStatusBuilder(Boolean validationEnabled) {
        this(new SubscriptionStatus(), validationEnabled);
    }

    public SubscriptionStatusBuilder(SubscriptionStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public SubscriptionStatusBuilder(SubscriptionStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SubscriptionStatus(), validationEnabled);
    }

    public SubscriptionStatusBuilder(SubscriptionStatusFluent<?> fluent,SubscriptionStatus instance) {
        this(fluent, instance, true);
    }

    public SubscriptionStatusBuilder(SubscriptionStatusFluent<?> fluent,SubscriptionStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAnnotations(instance.getAnnotations()); 
        fluent.withConditions(instance.getConditions()); 
        fluent.withObservedGeneration(instance.getObservedGeneration()); 
        fluent.withPhysicalSubscription(instance.getPhysicalSubscription()); 
        this.validationEnabled = validationEnabled; 
    }

    public SubscriptionStatusBuilder(SubscriptionStatus instance) {
        this(instance,true);
    }

    public SubscriptionStatusBuilder(SubscriptionStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAnnotations(instance.getAnnotations()); 
        this.withConditions(instance.getConditions()); 
        this.withObservedGeneration(instance.getObservedGeneration()); 
        this.withPhysicalSubscription(instance.getPhysicalSubscription()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.messaging.v1.EditableSubscriptionStatus build() {
        EditableSubscriptionStatus buildable = new EditableSubscriptionStatus(fluent.getAnnotations(),fluent.getConditions(),fluent.getObservedGeneration(),fluent.getPhysicalSubscription());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SubscriptionStatusBuilder that = (SubscriptionStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
